#include "uart.h"
#include <avr/pgmspace.h>
#include <string.h>

#define BAUD 9600

#include <util/setbaud.h>

void sendChar( char c )
{
	while ( ( USARTC0.STATUS & USART_DREIF_bm ) == 0) {}	// do nothing until data can be sent
	
	// Assign character to Data Register
	USARTC0.DATA = c;
}

void sendString( char* stringptr )
{
	while ( *stringptr )
	{
		sendChar( *stringptr );
		stringptr++;
	}
}

void init_uart(void)
{
	/* This PORT setting is only valid to USARTC0 if other USARTs is used a
	 * different PORT and/or pins are used. */
  	/* PC3 (TXD0) as output. */
	PORTC.DIRSET   = PIN3_bm;
	/* PC2 (RXD0) as input. */
	PORTC.DIRCLR   = PIN2_bm;

	// enable usart transmission and receive
	USARTC0.CTRLB |= USART_RXEN_bm | USART_TXEN_bm;

	// enabled usart RXC interrupt
	USARTC0.CTRLA |= USART_RXCINTLVL_LO_gc;
	
	// use 8bit character sizes
	USARTC0.CTRLC |= USART_CHSIZE_8BIT_gc | USART_CMODE_ASYNCHRONOUS_gc;
	
	// UBRR is 16 bit register
	// load lower 8 bits of baudrate value into UBRRL register
	USARTC0.BAUDCTRLA = UBRRL_VALUE;	
	
	// load higher 8 bits of baudrate value into UBRRH register
	USARTC0.BAUDCTRLB = UBRRH_VALUE;
}
